@@ -73,8 +73,11 @@ struct Totem {
 	BaconVideoWidget *bvw;
 	GtkWidget *prefs;
 	GtkWidget *statusbar;
+
+	/* Sidebar */
 	GtkWidget *sidebar;
 	gboolean sidebar_shown;
+	gboolean sidebar_ever_shown;
 
 	/* Separate Dialogs */
 	GtkWidget *properties;
@@ -92,6 +95,8 @@ struct Totem {
 	GtkAdjustment *seekadj;
 	gboolean seek_lock;
 	gboolean seekable;
+	gboolean was_playing;
+	gboolean seek_in_progress;
 
 	/* Volume */
 	GtkWidget *volume;
